Local product launcher
----------------------

Use the local product launcher rather than the launch functions implemented by various PyAnsys libraries. These pages provide an overview and describe how to use the local product launcher:

- :ref:`rationale`: Provides a high-level overview of the problem that the
  local product launcher solves.
- :ref:`ref_cli`: Describes the command-line interface.
- :ref:`plugin_creation`: Describes how to create a launcher plugin to
  extend   the local product launcher for use with another Ansys product.

.. toctree::
    :maxdepth: 2
    :caption: Contents

    rationale
    cli
    plugin_creation
